@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.6.7"
+    version = "1.6.9"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -119,10 +119,13 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         payload = f"{payload} > 出现次数: {group.times_seen} \n\n"
         payload = f"{payload} > 查看详情: <font color=blue>[{group.title if group.title else 'unknown'}]({issue_link})</font> \n\n"
         payload = f"{payload} > 具体报错: {group.message} \n\n"
-        payload = f"{payload} > 全部报错: {group} \n\n"
-        payload = f"{payload} > 全部报错: {group.__dict__} \n\n"
-        payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__} \n\n"
-        payload = f"{payload} > 阿明: {group._state} \n\n"
+        # payload = f"{payload} > 全部报错: {group} \n\n"
+        # payload = f"{payload} > 全部报错: {group.__dict__} \n\n"
+        # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__} \n\n"
+        # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__} \n\n"
+        payload = f"{payload} > _state: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['_state'].__dict__} \n\n"
+        payload = f"{payload} > _state: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['_state'].__dict__['fields_cache'].__dict__} \n\n"
+        # payload = f"{payload} > flags: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['flags'].__dict__} \n\n"
 
         headers = {
             "Content-type": "application/json",
